import { writable } from "svelte/store";
import { PopUpKind } from "./PopUpKind.js";
function createPopupStore() {
    const { subscribe, set, update } = writable(null);
    return {
        subscribe,
        show: (config) => set(config),
        hide: () => set(null),
        confirm: (userInput) => update((config) => {
            if (config) {
                config.onConfirm(userInput);
            }
            return null;
        }),
        cancel: () => update((config) => {
            if (config && config.onCancel) {
                config.onCancel();
            }
            return null;
        }),
    };
}
export class PopUpManager {
    popupStore;
    constructor() {
        this.popupStore = createPopupStore();
    }
    get store() {
        return this.popupStore;
    }
    show(config) {
        this.popupStore.show(config);
    }
    hide() {
        this.popupStore.hide();
    }
    confirm(userInput) {
        this.popupStore.confirm(userInput);
    }
    cancel() {
        this.popupStore.cancel();
    }
    handleButtonClicked(event) {
        const { value, userInput } = event.detail;
        value === "ok" ? this.confirm(userInput) : this.cancel();
    }
}
