import { as } from "../common/util/util.js";
export function getFirstNodeId(rootUlElem) {
    let firstNodeId = null;
    const firstNodeElem = as(rootUlElem.querySelector(".node-content[data-node-id]"));
    if (firstNodeElem) {
        firstNodeId = firstNodeElem.dataset.nodeId || null;
    }
    return firstNodeId;
}
export function getLastNodeId(rootUlElem) {
    let lastNodeId = null;
    const nodeElems = rootUlElem.querySelectorAll(".node-content[data-node-id]:last-child");
    if (nodeElems.length > 0) {
        const lastNodeElem = as(nodeElems[nodeElems.length - 1]);
        lastNodeId = lastNodeElem?.dataset.nodeId || null;
    }
    return lastNodeId;
}
export function getPrevNodeId(rootUlElem, nodeId) {
    let prevNodeId = null;
    const curNodeElem = as(rootUlElem.querySelector(`div.node-content[data-node-id="${nodeId}"]`));
    if (!curNodeElem)
        return null;
    const parentLi = as(curNodeElem.closest("li.node-item"));
    if (!parentLi)
        return null;
    const prevLi = as(parentLi.previousElementSibling);
    if (prevLi) {
        const prevNodeElem = as(prevLi.querySelector(".node-content[data-node-id]"));
        if (prevNodeElem) {
            prevNodeId = prevNodeElem.dataset.nodeId || null;
            if (prevNodeElem.dataset.nodeOpen === "true") {
                const childUl = as(prevLi.querySelector("ul[data-node-level]"));
                if (childUl) {
                    let nodes = childUl.querySelectorAll(".node-content[data-node-id]");
                    if (nodes.length > 0) {
                        const lastNode = nodes[nodes.length - 1];
                        prevNodeId = lastNode.dataset.nodeId || null;
                    }
                }
            }
        }
    }
    else {
        const parentNode = as(parentLi.parentNode);
        const prevNodeItem = as(parentNode?.closest("li.node-item"));
        if (prevNodeItem) {
            const prevNodeContent = prevNodeItem.querySelector(".node-content[data-node-id]");
            prevNodeId = prevNodeContent?.dataset.nodeId || null;
        }
    }
    return prevNodeId;
}
export function getNextNodeId(rootUlElem, nodeId) {
    let nextNodeId = null;
    const curNodeElem = as(rootUlElem.querySelector(`div.node-content[data-node-id="${nodeId}"]`));
    if (!curNodeElem)
        return null;
    const isNodeOpen = curNodeElem.dataset.nodeOpen === "true";
    const parentLi = as(curNodeElem.closest("li.node-item"));
    if (!parentLi)
        return null;
    if (isNodeOpen) {
        const childUl = as(parentLi.querySelector("ul[data-node-level]"));
        if (childUl) {
            const firstChildNode = as(childUl.querySelector(".node-content[data-node-id]"));
            nextNodeId = firstChildNode?.dataset.nodeId || null;
        }
    }
    if (!nextNodeId) {
        const nextLi = as(parentLi.nextElementSibling);
        if (nextLi) {
            const nextNodeContent = nextLi.querySelector(".node-content[data-node-id]");
            nextNodeId = nextNodeContent?.dataset.nodeId || null;
        }
    }
    if (!nextNodeId) {
        const parentUl = as(parentLi.closest("ul[data-node-level]"));
        if (parentUl) {
            const parentNode = as(parentUl.parentNode);
            const nextLi = as(parentNode?.nextElementSibling);
            if (nextLi) {
                const nextNodeContent = nextLi.querySelector(".node-content[data-node-id]");
                nextNodeId = nextNodeContent?.dataset.nodeId || null;
            }
        }
    }
    return nextNodeId;
}
