export default class IndexedDBManager {
    private dbName;
    private version;
    private db;
    private storeConfigs;
    constructor(dbName: string, version: number);
    addStoreConfig(storeName: string, keyPath: string, indexes?: Array<{
        name: string;
        keyPath: string | string[];
        unique: boolean;
    }>): void;
    openDatabase(): Promise<IDBDatabase>;
    getDatabase(): Promise<IDBDatabase>;
    getData<T>(storeName: string, key: IDBValidKey): Promise<T | undefined>;
    saveData<T>(storeName: string, data: T, key?: IDBValidKey | null, overwrite?: boolean): Promise<IDBValidKey>;
    deleteData(storeName: string, key: IDBValidKey): Promise<void>;
    getDataByIndex<T>(storeName: string, indexName: string, key: IDBValidKey): Promise<T[]>;
    getRecordCount(storeName: string): Promise<number>;
    closeDatabase(): void;
    static getStoreInfo(dbName: string, version: number, storeName: string): Promise<{
        keyPath: string;
        indexes: {
            name: string;
            keyPath: string | string[];
            unique: boolean;
        }[];
        recordCount: number;
    } | null>;
    static getAllData<T>(dbName: string, version: number, storeName: string): Promise<T[]>;
}
export declare const promisifyRequest: <T>(request: IDBRequest<T>) => Promise<T>;
export declare const promisifyTransaction: (transaction: IDBTransaction) => Promise<void>;
